add_interceptor("/charpane.php", function()
-- name
-- level / progress
-- mus / mys / mox
-- full / drunk / spleen
-- hp / maxhp
-- mp / maxmp
-- meat
-- advs
-- mcd
-- semirare
-- turnsplayed
-- familiar
-- weight
-- bonus
-- buffs
	local function pathdesc()
		local prefix = ""
		if ascensionstatus() == "Hardcore" then
			prefix = "HC"
		elseif ascensionstatus() == "Softcore" then
			prefix = "SC"
		end
		if ascensionpath() == "Bad Moon" then
			return "BM"
		elseif ascensionpath() == "Teetotaler" then
			return prefix .. "T"
		elseif ascensionpath() == "Boozetefarian" then
			return prefix .. "B"
		elseif ascensionpath() == "Oxygenarian" then
			return prefix .. "O"
		else
			if prefix ~= "" then
				return prefix .. "NP"
			else
				return ""
			end
		end
	end

	local function classdesc()
		return ({ "SC", "TT", "PM", "S", "DB", "AT" })[classid()]
	end
	local function classpathdesc()
		local p = pathdesc()
		if p ~= "" then
			return string.format("%s %s", p, classdesc())
		else
			return classdesc()
		end
	end

	local function substatstolevel()
		local x = level() + 1
		local needstat = (x - 1) * (x - 1) + 4
		local needsubstat = needstat * needstat
		return needsubstat
	end

	local function format_integer(i)
		if i >= 1000 then
			local upper = math.floor(i / 1000)
			return format_integer(upper) .. "," .. string.format("%03d", i - upper * 1000)
		else
			return i
		end
	end

	local function format_hpmp(c, m)
		if c == m then
			return string.format([[<span style="color: green">%s</span>]], format_integer(c))
		elseif c < m * 0.25 then
			return string.format([[<span style="color: red">%s / %s</span>]], format_integer(c), format_integer(m))
		else
			return string.format([[%s / %s]], format_integer(c), format_integer(m))
		end
	end

	local function get_srdata()
		local SRnow, good_numbers, all_numbers, SRmin, SRmax, is_first_semi, lastsemi = get_semirare_info(turnsthisrun())
		local value = ""
		local color = "black"
		if SRnow then
			color = "green"
		end
		if table.maxn(good_numbers) > 0 then
			value = good_numbers[1]
			for x, _ in pairs(good_numbers) do
				if x > 1 then
					value = value .. "+"
				end
			end
		else
			value = "?"
		end

		if (not lastsemi) and (not is_first_semi) then
			lastsemi = "?"
		end
		
		local tooltip = ""
		if table.maxn(all_numbers) > 0 then
			tooltip = tooltip .. "Fortune cookie numbers: " .. table.concat(all_numbers, ", ")
		else
			tooltip = tooltip .. "Fortune cookie numbers: ?"
		end

		if SRmin and SRmax and SRmax >= 0 then
			if value == "?" then
				value = SRmin .. " to " .. SRmax
			end
			tooltip = tooltip .. ", range = " .. SRmin .. " to " .. SRmax
		else
			if value ~= "?" then
				value = value .. "?"
			end
			tooltip = tooltip .. ", range = ?"
		end

		if lastsemi then
			tooltip = tooltip .. ", last semirare = " .. lastsemi
		end
		local bgcolor = "white"
		local showlast = nil
		if SRnow then
			bgcolor = "green"
			if lastsemi then
				showlast = lastsemi
			end
		end

		local srdata = string.format([[SR: <span style="color: ]]..color..[[" title="]]..tooltip..[["><b>%s</b></span>]], value)

		return bgcolor, srdata
	end

	local bgcolor, srdata = get_srdata()

	local lines = {}
	table.insert(lines, string.format([[<a class="nounder" target="mainpane" href="charsheet.php"><b>%s</b></a> <span class="tiny">(%s)</span>]], playername(), classpathdesc()))
	table.insert(lines, string.format([[Level: <b>%s</b> <span class="tiny">(%s to go)</span>]], level(), format_integer(substatstolevel() - rawmainstat())))
-- 	table.insert(lines, string.format([[Mainstat: <b><span style="color: blue; font-weight: bold;">%s</span> (%s)</b>]], format_integer(buffedmainstat()), format_integer(basemainstat())))
	table.insert(lines, string.format([[Buffed: <b><span style="color: blue; font-weight: bold;">%s</span></b> / <b><span style="color: blue; font-weight: bold;">%s</span></b> / <b><span style="color: blue; font-weight: bold;">%s</span></b>]], format_integer(buffedmuscle()), format_integer(buffedmysticality()), format_integer(buffedmoxie())))
	table.insert(lines, string.format([[Base: <b>%s</b> / <b>%s</b> / <b>%s</b>]], format_integer(basemuscle()), format_integer(basemysticality()), format_integer(basemoxie())))
	table.insert(lines, string.format([[Organs: <b>%s</b> / <b>%s</b> / <b>%s</b>]], fullness(), drunkenness(), spleen()))
	table.insert(lines, "")
	table.insert(lines, string.format([[HP: <b>%s</b>]], format_hpmp(hp(), maxhp())))
	table.insert(lines, string.format([[MP: <b>%s</b>]], format_hpmp(mp(), maxmp())))
	table.insert(lines, string.format([[Meat: <b>%s</b>]], format_integer(meat())))
	table.insert(lines, string.format([[Played: <b>%s</b> <span class="tiny">(%s left)</span>]], turnsthisrun(), advs()))
	table.insert(lines, "")
	table.insert(lines, srdata)
	table.insert(lines, "")

-- 	TODO: familiars

	local text = [[
<html>
<head>
  <style type="text/css">
body {
	font-family: Arial, Helvetica, sans-serif;
	background-color: ]] .. bgcolor .. [[;
	color: black;
	font-size: 0.8em;
}
td {
	font-family: Arial, Helvetica, sans-serif;
}
a:link { color: black; }
a:visited {	color: black; }
a:active { color: black; }
.nounder { text-decoration: none; }
.tiny { font-size: 0.9em; }
  </style>
</head>
<body>
]] .. table.concat(lines, "<br>") .. [[
</body>
</html>]]
	return text, "/kolproxy-quick-charpane"
end)

-- game.php
-- <frameset id=mainset cols="120,*">
-- <frameset id=mainset cols="200,*">
